@@ -28,6 +28,9 @@ class ClimateDevice(NamedTuple):
     hvac_modes: List[str]
     preset_mode: str
     preset_modes: List[str]
+    fan_mode: Optional[str]
+    fan_modes: Optional[List[str]]
+    locked: Optional[bool]
     supported_features: int
     device_class: str
     data: dict
